@@ -27,6 +27,7 @@
 #include <libintl.h>
 #include <locale.h>
 #include <dirent.h>
+#include <unistd.h>
 
 #define SCROLLKEEPERLOCALEDIR "/usr/share/locale"
 
@@ -231,8 +232,15 @@ static int parse_omf_dir(char *path, char **name_tab, int name_num,
 
 	if (i != *install_num)
 	{
+	    /*
+	     * Commenting out because these warnings should go in
+	     * a log file for an admin to watch, not on the screen for
+	     * the user to see and worry about.  Plus, in some cases
+	     * it makes RPM think things are broken and that the
+	     * upgrade or install failed.
 	    fprintf (stderr, _("%s: warning: %s overrides %s\n"), *av,
 		     (*install_tab)[i], fullname);
+	    */
 	}
 	else
 	{
@@ -289,24 +297,23 @@ colon_split (char *s)
 
 int main(int argc, char **argv)
 {
-    FILE *fid1, *fid2, *config_fid;
+    FILE *fid1, *config_fid;
     char name[PATHLEN];
     long t;
     struct stat buf;
     int line_num = 0, i;
-    char **name_tab = NULL, **elem;
+    char **name_tab = NULL;
     char **install_tab = NULL, **uninstall_tab = NULL;
     int install_num = 0, upgrade_num = 0, uninstall_num = 0;
     char scrollkeeper_dir[PATHLEN], omf_dir[PATHLEN];
     char **omf_dirs = NULL;
     char scrollkeeper_docs[PATHLEN], command[1024];
     char **upgrade_tab = NULL;
-    char fullname[PATHLEN];
     char *s, **cpp;
     int verbose = 0;
 
-    extern int optind;
-    extern char *optarg;
+    /*extern int optind;
+    extern char *optarg;*/
 
     av = argv;
     
@@ -346,6 +353,16 @@ int main(int argc, char **argv)
     	pclose(config_fid);
     }
 
+    /*
+     * Create the database directory if it does not exist
+     */
+    if (stat (scrollkeeper_dir, &buf) != 0)
+    {
+        if (mkdir (scrollkeeper_dir,0755)) {
+            fprintf(stderr,"Unable to create database directory: %s\n",scrollkeeper_dir);
+        }
+    }
+
     /*
      * Command line wins; environmental variable gets second priority;
      * use scrollkeeper-config if neither is available.
